summaryrefslogtreecommitdiffstats
path: root/kandy/src/mobilegui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/mobilegui.cpp')
-rw-r--r--kandy/src/mobilegui.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kandy/src/mobilegui.cpp b/kandy/src/mobilegui.cpp
index 08cf54cc..70d0656f 100644
--- a/kandy/src/mobilegui.cpp
+++ b/kandy/src/mobilegui.cpp
@@ -176,21 +176,21 @@ class PhoneBookItem : public TQCheckListItem
/*
* Constructs a MobileGui which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
MobileGui::MobileGui( CommandScheduler *scheduler, KandyPrefs *kprefs,
- TQWidget* tqparent, const char* name, WFlags fl ) :
- DCOPObject( "KandyIface" ), MobileGui_base( tqparent, name, fl )
+ TQWidget* parent, const char* name, WFlags fl ) :
+ DCOPObject( "KandyIface" ), MobileGui_base( parent, name, fl )
{
// Setup links to related classes
mScheduler = scheduler;
mSyncer = new AddressSyncer;
mPrefs = kprefs;
- mtqparent = tqparent;
+ mparent = parent;
// Setup mobile phone specific data
mMobManufacturer = "";
@@ -1463,7 +1463,7 @@ void MobileGui::toggleConnection()
setKabState( UNLOADED );
setMobState( UNLOADED );
- ((MobileMain *) mtqparent)->statusBar()->changeItem( i18n(" Connected "), 1 );
+ ((MobileMain *) mparent)->statusBar()->changeItem( i18n(" Connected "), 1 );
} else {
warnKabState( UNLOADED );
@@ -1510,7 +1510,7 @@ void MobileGui::disconnectGUI()
mPBIndexOccupied.resize( 0, false );
- ((MobileMain *) mtqparent)->statusBar()->changeItem( i18n(" Disconnected "),
+ ((MobileMain *) mparent)->statusBar()->changeItem( i18n(" Disconnected "),
1 );
}
@@ -176,21 +176,21 @@ class PhoneBookItem : public TQCheckListItem
/*
- * Constructs a MobileGui which is a child of 'tqparent', with the
+ * Constructs a MobileGui which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*